SetCompressor /SOLID lzma

# You must call makensis.exe with /DVersion=<version num>
# to specify the version number

# to be overriden by the build command line
# $ makensis /DProduct "product_name" installer/simplelauncher.nsi
# !define Product "simplelauncher"

!define MUI_UninstallName "Uninstall ${Product}"

!include "MUI.nsh"

!define TEMP $R0

;--------------------------------
;Configuration

    XPStyle on
    outFile ..\installer\${Product}-${Version}.exe
    InstallDir "$PROGRAMFILES\${Vendor}\${Product}"
    ; override InstallDir if the reg key is present...
    ; ie if our prog is already installed
    InstallDirRegKey HKLM "SOFTWARE\${Vendor}\${Product}" "Install_Dir"
    ; to be set by user

    !Define ICONE "..\data\py.ico"

;---------------------------------
;Moderne UI configuration

    XPStyle on
    BrandingText "Launcher Engine Installer"
    !Define MUI_NAME "${Product}"

    !Define MUI_WELCOMEPAGE
    !define MUI_LICENCEPAGE
    !define MUI_COMPONENTSPAGE    
    !define MUI_DIRECTORYPAGE
    !Define MUI_FINISHPAGE
    !define MUI_ICON "${ICONE}"

    !define MUI_UNINSTALLER
    !define MUI_UNCONFIRMPAGE
    !define MUI_UNFINISHPAGE
    !define MUI_UNICON "${ICONE}"

    ; Pages
    !insertmacro MUI_PAGE_COMPONENTS
    !insertmacro MUI_PAGE_DIRECTORY

    ; back to normal flow
    !insertmacro MUI_PAGE_INSTFILES
    !insertmacro MUI_UNPAGE_WELCOME
    !insertmacro MUI_UNPAGE_CONFIRM
    !insertmacro MUI_UNPAGE_INSTFILES
    !insertmacro MUI_UNPAGE_FINISH

;---------------------------------
;LanguagesReadRegStr

        Name ${Product}
        
        !insertmacro MUI_LANGUAGE "English"

;---------------------------------
;Section d'installation

section "Installation Launcher" SecInstall

    SectionIn RO

    SetOverWrite On

    SetOutPath $INSTDIR
    File /r "${SRCDIR}\*.*"

    SetOutPath $INSTDIR
    File /r "${USRDIR}\*.*"

    WriteRegStr HKLM "SOFTWARE\${Vendor}\${Product}" "Install_Dir" "$INSTDIR"
    
    WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${Product}" "DisplayName" "${Product}-${Version}"
    WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${Product}" "DisplayVersion" "${Version}"
    WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${Product}" "VersionMajor" "${MajorVersion}"
    WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${Product}" "VersionMinor" "${MinorVersion}"
    WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${Product}" "UninstallString" '"$INSTDIR\${MUI_UninstallName}.exe"'    
    WriteUninstaller "${MUI_UninstallName}.exe"    
Sectionend

Function .onInit
    
    ; make sure the installer is not running already
    System::Call 'kernel32::CreateMutexA(i 0, i 0, t "PyLauncherMutex") i .r1 ?e'
    Pop $R0
    StrCmp $R0 0 +3
    MessageBox MB_OK|MB_ICONEXCLAMATION "The installer is already running."
    Abort

    ; Check for Admin rights
    ClearErrors
    UserInfo::GetAccountType
    Pop $0
    # compare the result with the string "Admin" to see if the user is admin.
    # If match, jump 4 lines down.
    StrCmp $0 "Admin" +3
    ; if not Admin then a pop up
    MessageBox MB_OK|MB_ICONEXCLAMATION "This installer needs Administrators privileges"
    Abort

FunctionEnd

;--------------------------------
;Uninstaller Functions

Section "Uninstall"

    DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${Product}"
    DeleteRegKey HKLM "SOFTWARE\${Vendor}\${Product}"
    DeleteRegKey HKCU "Software\${Vendor}\${Product}"

    ; delete the instdir if possible
    RMDIR /r "${INSTDIR}"
    RMDIR "${INSTDIR}"
        
SectionEnd

Function un.onInit

       ;!insertmacro MUI_UNGETLANGUAGE
  
FunctionEnd

;--------------------------------
;Descriptions

    !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${SecInstall} "Install ${Product}"

!insertmacro MUI_FUNCTION_DESCRIPTION_END
